==> lclint_2.1b-1.tar.gz: lclint-2.1b/src/Headers/paramNodeList.h <==
/*
** Copyright (c) Massachusetts Institute of Technology 1994, 1995, 1996.
**          All Rights Reserved.
**          Unpublished rights reserved under the copyright laws of
**          the United States.
**
** THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
** OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
**
** This code is distributed freely and may be used freely under the 
** following conditions:
**
**     1. This notice may not be removed or altered.
**
**     2. This code may not be re-distributed or modified
**        without permission from MIT (contact 
**        lclint-request@larch.lcs.mit.edu.)  
**
**        Modification and re-distribution are encouraged,
**        but we want to keep track of changes and
**        distribution sites.
*/
# ifndef paramNodeLIST_H
# define paramNodeLIST_H

typedef /*@null@*/ /*@only@*/ paramNode o_paramNode;

abst_typedef /*@null@*/ struct _paramNodeList
{
  int nelements;
  int nspace;
  /*@reldef@*/ /*@relnull@*/ o_paramNode *elements;
} *paramNodeList ;

/*@iter paramNodeList_elements (sef paramNodeList x, yield exposed paramNode el); @*/
# define paramNodeList_elements(x, m_el) \
    if (paramNodeList_isDefined (x)) \
      { int m_ind; paramNode *m_elements = &((x)->elements[0]); \
        for (m_ind = 0 ; m_ind < (x)->nelements; m_ind++) \
          { paramNode m_el = *(m_elements++); 

# define end_paramNodeList_elements }}

extern int paramNodeList_size (/*@sef@*/ paramNodeList);

# define paramNodeList_size(s)  (paramNodeList_isDefined (s) ? (s)->nelements : 0)   

extern bool paramNodeList_empty (/*@sef@*/ paramNodeList s);
# define paramNodeList_empty(s) (paramNodeList_size(s) == 0)

extern /*@only@*/ paramNodeList paramNodeList_single (/*@keep@*/ paramNode p);

extern /*@falsenull@*/ bool paramNodeList_isDefined (paramNodeList s) /*@*/ ;
# define paramNodeList_isDefined(s) ((s) != (paramNodeList)0)
extern /*@only@*/ paramNodeList paramNodeList_new (void);

extern paramNodeList 
  paramNodeList_add (/*@returned@*/ paramNodeList x, /*@null@*/ /*@only@*/ paramNode n) ;

extern /*@only@*/  cstring paramNodeList_unparse (paramNodeList s) ;
extern void paramNodeList_free (/*@only@*/ /*@only@*/ paramNodeList s) ;

extern /*@only@*/ paramNodeList paramNodeList_copy (paramNodeList s) ; 
extern /*@only@*/ cstring paramNodeList_unparseComments (paramNodeList s);

/*@constant int paramNodeListBASESIZE;@*/
# define paramNodeListBASESIZE SMALLBASESIZE

/*@constant null paramNodeList paramNodeList_undefined; @*/
# define paramNodeList_undefined ((paramNodeList) 0)

extern /*@truenull@*/ bool paramNodeList_isNull (/*@null@*/ paramNodeList p);

# define paramNodeList_isNull(p) ((p) == paramNodeList_undefined)

# else
# error "Multiple include"
# endif

==> lclint_2.4b.orig.tar.gz: lclint-2.4b/src/Headers/paramNodeList.h <==
/*
** Copyright (c) Massachusetts Institute of Technology 1994-1998.
**          All Rights Reserved.
**          Unpublished rights reserved under the copyright laws of
**          the United States.
**
** THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
** OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
**
** This code is distributed freely and may be used freely under the 
** following conditions:
**
**     1. This notice may not be removed or altered.
**
**     2. Works derived from this code are not distributed for
**        commercial gain without explicit permission from MIT 
**        (for permission contact lclint-request@sds.lcs.mit.edu).
*/
# ifndef paramNodeLIST_H
# define paramNodeLIST_H

typedef /*@null@*/ /*@only@*/ paramNode o_paramNode;

abst_typedef /*@null@*/ struct _paramNodeList
{
  int nelements;
  int nspace;
  /*@reldef@*/ /*@relnull@*/ o_paramNode *elements;
} *paramNodeList ;

/*@iter paramNodeList_elements (sef paramNodeList x, yield exposed paramNode el); @*/
# define paramNodeList_elements(x, m_el) \
    if (paramNodeList_isDefined (x)) \
      { int m_ind; paramNode *m_elements = &((x)->elements[0]); \
        for (m_ind = 0 ; m_ind < (x)->nelements; m_ind++) \
          { paramNode m_el = *(m_elements++); 

# define end_paramNodeList_elements }}

extern int paramNodeList_size (/*@sef@*/ paramNodeList);

# define paramNodeList_size(s)  (paramNodeList_isDefined (s) ? (s)->nelements : 0)   

extern bool paramNodeList_empty (/*@sef@*/ paramNodeList p_s);
# define paramNodeList_empty(s) (paramNodeList_size(s) == 0)

extern /*@only@*/ paramNodeList paramNodeList_single (/*@keep@*/ paramNode p_p);

extern /*@falsenull@*/ bool paramNodeList_isDefined (paramNodeList p_s) /*@*/ ;
# define paramNodeList_isDefined(s) ((s) != (paramNodeList)0)
extern /*@only@*/ paramNodeList paramNodeList_new (void);

extern paramNodeList 
  paramNodeList_add (/*@returned@*/ paramNodeList p_s, /*@null@*/ /*@only@*/ paramNode p_el) ;

extern /*@only@*/  cstring paramNodeList_unparse (paramNodeList p_s) ;
extern void paramNodeList_free (/*@only@*/ /*@only@*/ paramNodeList p_s) ;

extern /*@only@*/ paramNodeList paramNodeList_copy (paramNodeList p_s) ; 
extern /*@only@*/ cstring paramNodeList_unparseComments (paramNodeList p_s);

/*@constant int paramNodeListBASESIZE;@*/
# define paramNodeListBASESIZE SMALLBASESIZE

/*@constant null paramNodeList paramNodeList_undefined; @*/
# define paramNodeList_undefined ((paramNodeList) 0)

extern /*@truenull@*/ bool paramNodeList_isNull (/*@null@*/ paramNodeList p_p);

# define paramNodeList_isNull(p) ((p) == paramNodeList_undefined)

# else
# error "Multiple include"
# endif
